# Ubuntu CI Engine
# Copyright 2014 Canonical Ltd.

# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License version 3, as
# published by the Free Software Foundation.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU Affero General Public License for more details.

# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import unittest

from ucitests import assertions


from britney import process_requests
from ci_utils.testing import (
    features,
    fixtures,
)


# FIXME: This works around https://app.asana.com/0/8499154990155/14496314215756
# 'unit_config as a fixture for tests that requires it' -- vila 2014-09-25
@features.requires(features.nova_creds)
class TestBritneyRequestHandler(unittest.TestCase):

    def setUp(self):
        super(TestBritneyRequestHandler, self).setUp()
        self.test_runner_queue = fixtures.FakeTaskQueue('test_runner.requests')
        self.handler = process_requests.BritneyRequestHandler(
            self.test_runner_queue, 'not used in these tests')

    def test_translate_request_amd64(self):
        series = 'precise'
        params = dict(architecture='amd64',
                      series=series,
                      package='libpng')
        self.handler.handle(params)
        assertions.assertLength(self, 1, self.test_runner_queue.msgs)
        tr_params = self.test_runner_queue.msgs[0]
        assertions.assertLength(self, 1, tr_params['package_list'])
        self.assertEquals('libpng', tr_params['package_list'][0])

    def test_translate_request_i386(self):
        series = 'precise'
        params = dict(architecture='i386',
                      series=series,
                      package='libpng')
        self.handler.handle(params)
        # We don't (yet) support i386 so the request is dropped
        assertions.assertLength(self, 0, self.test_runner_queue.msgs)
